'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

// FILE: ./assets/modules/produto/templates/controllers/SafraController.js
var SafraController = function SafraController($scope, templateManager, $element) {

	var currentSelectedElement;

	this.TColorToHex = function (TColor) {
		var rgb = this.TColorToRGB(TColor);
		return this.rgbToHex(rgb);
	};

	this.TColorToRGB = function (TColor) {
		var r = TColor & 0xFF;
		var g = TColor >> 8 & 0xFF;
		var b = TColor >> 16 & 0xFF;
		return [r, g, b];
	};

	this.rgbToHex = function (rgb) {
		return "#" + ((1 << 24) + (rgb[0] << 16) + (rgb[1] << 8) + rgb[2]).toString(16).slice(1);
	};

	this.initColors = function (field) {
		var currentRow = $scope.field.widget.currentRow;
		var safra = currentRow[field.colorsFlag.OPTION1];
		var initFin = currentRow[field.colorsFlag.OPTION2];
		var entre = currentRow[field.colorsFlag.OPTION3];

		var htmlParentContainer = $element.get(0);
		var flagElements = htmlParentContainer.querySelectorAll('.flag');

		safra = safra ? this.TColorToHex(safra) : 'transparent';
		initFin = initFin ? this.TColorToHex(initFin) : 'transparent';
		entre = entre ? this.TColorToHex(entre) : 'transparent';

		flagElements[0].style.backgroundColor = safra;
		flagElements[1].style.backgroundColor = initFin;
		flagElements[2].style.backgroundColor = entre;

		var colorMonths = currentRow[field.propertieToChange];
		var months = htmlParentContainer.querySelectorAll('.month');
		this.initColorsMonth(months, [safra, initFin, entre], colorMonths);
	};

	this.initColorsMonth = function (months, colorFlags, colorMonths) {
		var color;
		if (!colorMonths) {
			months.forEach(function (element, key) {
				element.children[1].style.backgroundColor = 'transparent';
			});
		} else {
			colorMonths = colorMonths.split('');
			months.forEach(function (element) {
				var month = $(element).attr('month');
				var monthCorlorElement = element.children[1];

				var codeFlag = colorMonths[month - 1];
				var colorMonth = codeFlag != ' ' ? colorFlags[codeFlag - 1] : 'transparent';

				monthCorlorElement.style.backgroundColor = colorMonth;
			});
		}
	};

	this.getOptLabel = function (field, opt) {
		if (opt == '1') {
			return field.option1 === "" || field.option1 ? field.option1 : "option1 not found";
		} else if (opt == '2') {
			return field.option2 === "" || field.option2 ? field.option2 : "option2 not found";
		} else {
			return field.option3 === "" || field.option3 ? field.option3 : "option3 not found";
		}
	};

	this.selectFlag = function ($event) {
		if (this.isEdit()) {
			if (currentSelectedElement === $event.currentTarget) {
				currentSelectedElement.style.backgroundColor = "transparent";
				currentSelectedElement = null;
			} else {
				if (currentSelectedElement) {
					currentSelectedElement.style.backgroundColor = "transparent";
				}
				currentSelectedElement = $event.currentTarget;
				currentSelectedElement.style.backgroundColor = '#67a965';
			}
		}
	};

	this.setInMonth = function ($event, field) {
		if (this.isEdit() && currentSelectedElement) {
			var flagElement = currentSelectedElement.children[0];
			var color = flagElement.style.backgroundColor;
			var monthElement = $event.currentTarget.children[1];
			monthElement.style.backgroundColor = color;
			var month = $($event.currentTarget).attr('month');
			this.changePropertieInCurrentRow(field, month);
		}
	};

	this.changePropertieInCurrentRow = function (field, month) {
		if (!field.propertieToChange) {
			throw 'propertieToChange not found';
		} else {
			var option = $(currentSelectedElement).attr('option');
			var propertieToChange = field.propertieToChange;
			var value;
			if (!field.widget.currentRow[propertieToChange]) {
				value = '          ';
			} else {
				value = field.widget.currentRow[propertieToChange];
			}
			value = value.split('');
			value[month - 1] = option;
			value = value.join('');
			field.widget.currentRow[propertieToChange] = value;
		}
	};

	this.isEdit = function () {
		var widget = $scope.field.widget;
		if (widget.mode === 'edit') {
			return true;
		} else {
			return false;
		}
	};

	this.isCurrentMonth = function (month) {
		var currentMonth = moment().month() + 1;
		if (currentMonth == month) {
			return true;
		} else {
			return false;
		}
	};

	$scope.$watch(function () {
		return templateManager.container ? templateManager.container.getActiveWidget().currentRow : false;
	}, function () {
		var widget = templateManager.container.getActiveWidget();
		var fieldsSafra = widget.fields.filter(function (field) {
			return field.template === 'safra-component#field/safra.html' && field.isVisible;
		});
		fieldsSafra.forEach(function (field) {
			this.initColors(field);
		}, this);
	}.bind(this));
};

// FILE: ./assets/modules/produto/templates/controllers/register.js
var register = function register(decodeTemplateFieldService, eventAggregator) {
	eventAggregator.subscribe('beforeProjectStartup', function register() {
		decodeTemplateFieldService.registerViewTemplate('safra-component#field/safra.html', 'safra-component#field/safra.html');
	});
};

Configuration(function (ContextRegister, eventEngine) {
	ContextRegister.register('register', register);
});

(function registerTemplates() {
	window.templateUrls = window.templateUrls || [];
	window.templateUrls.push({
		'package': 'safra-component',
		'baseUrl': './assets/modules/produto/templates/'
	});
})();

// FILE: ./assets/modules/produto/assets/js/utilities/produtoValidations.js
var produtoValidations = function produtoValidations(ScreenService, templateManager, ValidationEngine, MessageService) {

	var validSemiLevel = function validSemiLevel(value, use) {

		/* MSG NOVA */
		var variaveis = {
			LEVELMASKPROD: getLevelMaksPenul()
		};

		/* FIM MSG NOVA */

		return {
			"valid": validLevel(value, use),
			"message": MessageService.showMessageByCode("GETLEVELMASKPROD", variaveis, { "type": "error" })
		};
		// "message": ScreenService.i18n('Nível do produto deve ser igual a '+getLevelMaksPenul())
	};

	var validNivante = function validNivante(value, params) {
		return {
			"valid": validRealNivante(value, params.widgetName, params.nivanteValue),
			"message": ScreenService.i18n(params.message || 'Código inválido para produto pai selecionado.')
		};
	};

	ValidationEngine.registerValidation('containsNivante', validNivante);
	ValidationEngine.registerValidation('penultimateLevel', validSemiLevel);

	function validLevel(value, use) {
		var rightValue = getLevelMaksPenul();
		if (value != rightValue && use) {
			return false;
		} else {
			return true;
		}
	}

	function validRealNivante(value, widgetName, cdnivanteName) {
		var widget = templateManager.container.getWidget(widgetName);
		var cdnivante = widget.currentRow[cdnivanteName] || null;
		var valueDesmasked = value.split('.').join('');

		if (cdnivante && cdnivante !== valueDesmasked.substr(0, cdnivante.length)) {
			return false;
		} else {
			return true;
		}
	}

	function getLevelMaksPenul() {
		var mask = getMaskPenulLevel();
		mask = mask.split('.');
		return mask.length;
	}

	function getMaskPenulLevel() {
		var mask = getLocalVar('GER_CDPICTPROD');
		mask = mask.split('.');
		mask.pop();
		return mask.join('.');
	}
};

Configuration(function (ContextRegister, eventEngine) {
	ContextRegister.register('produtoValidations', produtoValidations);
});

// FILE: ./assets/modules/produto/assets/js/controllers/ColorPickerController.js
function ColorPickerController() {

	this.TColorToHex = function (TColor) {
		var rgb = this.TColorToRGB(TColor);
		return this.rgbToHex(rgb);
	};

	this.TColorToRGB = function (TColor) {
		var r = TColor & 0xFF;
		var g = TColor >> 8 & 0xFF;
		var b = TColor >> 16 & 0xFF;
		return [r, g, b];
	};

	this.rgbToHex = function (widget) {
		var r = widget.currentRow.CORCONFIGURACAO._r;
		var g = widget.currentRow.CORCONFIGURACAO._g;
		var b = widget.currentRow.CORCONFIGURACAO._b;
		widget.currentRow.CORCONFIGURACAO = "#" + ((1 << 24) + (Math.floor(r) << 16) + (Math.floor(g) << 8) + Math.floor(b)).toString(16).slice(1);
	};

	this.hexToRgb = function (hex) {
		var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
		return result ? {
			r: parseInt(result[1], 16),
			g: parseInt(result[2], 16),
			b: parseInt(result[3], 16)
		} : null;
	};

	this.rgbToHexOnRow = function (row, field) {
		var r = row[field]._r;
		var g = row[field]._g;
		var b = row[field]._b;
		row[field] = "#" + ((1 << 24) + (Math.floor(r) << 16) + (Math.floor(g) << 8) + Math.floor(b)).toString(16).slice(1);
		return row[field];
	};

	this.rgbToHexOnRowWithoutHash = function (row, field) {
		var r = row[field]._r;
		var g = row[field]._g;
		var b = row[field]._b;
		row[field] = ((1 << 24) + (Math.floor(r) << 16) + (Math.floor(g) << 8) + Math.floor(b)).toString(16).slice(1);
		return row[field];
	};

	this.RGBToTColor = function (r, g, b) {
		var Tcolor = r | g << 8 | b << 16;
		return Tcolor;
	};
}

Configuration(function (ContextRegister) {
	ContextRegister.register('ColorPickerController', ColorPickerController);
});

// FILE: ./assets/modules/produto/assets/js/controllers/LayoutController.js
function LayoutController(General, ScreenService, ColorPickerController, restEngine, templateManager) {

	var self = this;
	var TAMANHO_FONTE_PADRAO = '08';

	this.setCicloColor = function (element, row, fieldName) {
		if (("" + row[fieldName]).charAt(0) != '#') self.convertTColorToHexa(row);
		if (row) {
			if (element.hasClass('zh-span-field ng-scope')) {
				element.find('p').css('background-clip', 'content-box');
				element.find('p').css('background-color', '#' + row[fieldName]);
				element.find('p').css('color', '#' + row[fieldName]);
			} else if (element.hasClass('td zh-standard-column  grid-align-left')) {
				element.find('p').css('background-clip', 'content-box');
				element.find('span').css('background-color', '#' + row[fieldName]);
				element.find('span').css('color', '#' + row[fieldName]);
				element.find('span').css('display', 'block');
			}
		}
	};

	this.convertTColorToHexa = function (row) {
		if (!isNaN(row.NRCOLORBACK)) {
			row.NRCOLORBACK = this.colorChange(row.NRCOLORBACK);
		}
		if (!isNaN(row.NRCOLORTEXT)) {
			row.NRCOLORTEXT = this.colorChange(row.NRCOLORTEXT);
		}
	};

	this.colorChange = function (Cor) {
		var r = Cor & 0XFF;
		var g = Cor >> 8 & 0xFF;
		var b = Cor >> 16 & 0XFF;
		var Hexa = "#" + ((1 << 24) + (Math.floor(r) << 16) + (Math.floor(g) << 8) + Math.floor(b)).toString(16).slice(1);
		return Hexa;
	};

	this.newRowGruposDeProdutos = function (args) {
		var widget = args.owner.widget;
		if (widget.bkpRow) widget.currentRow = widget.bkpRow;
		var row = widget.currentRow;
		widget.bkpRow = Util.clone(widget.currentRow);
		General.widgetNewRow(widget);

		widget.getField("NRBUTTON").readOnly = widget.getField("DSBUTTON").readOnly = row.__is_new = true;
		row.ANTG_NRBUTTON = '';
		row.CDNATPRODUTO = null;
		row.IDTPBUTTON = 1;
		row.NMPRODUTO = General.getFieldValue('NMPRODUTO', 'Detalhamento');
		row.CDPRODUTO = General.getFieldValue('CDPRODUTO', 'Detalhamento');
		row.CDARVPROD = General.getFieldValue('CDARVPROD', 'Detalhamento');

		var filterData = !widget.appliedFilter ? widget.appliedFilter.FILTER_ROW : false;

		if (!!filterData && !!filterData.CDFILIAL) {
			widget.getField('NMCONFTELA').readOnly = false;
			widget.getField('NMFILIAL').readOnly = true;
			row.NMFILIAL = filterData.NMFILIAL;
			row.CDFILIAL = filterData.CDFILIAL;
		} else {
			widget.getField('NMFILIAL').readOnly = false;
			widget.getField('NMCONFTELA').readOnly = true;
		}

		row.DSBUTTON2 = row.NMPRODUTO;
		row.NRFONTETEXT = TAMANHO_FONTE_PADRAO;
		row.NRCOLORBACK = '#fff';
		row.NRCOLORTEXT = '#ff5500';
		widget.currentRow = row;
		widget.reload();
	};

	this.editRowGruposDeProdutos = function (args) {
		var widget = args.owner.widget;
		General.widgetEdit(widget);
		widget.getField("NRBUTTON").readOnly = true;
		widget.currentRow.__is_new = false;
		widget.currentRow.ANTG_NRBUTTON = widget.currentRow.NRBUTTON;
		widget.reload();
	};

	this.changeFieldNRPGCONFTELA = function (args) {
		var widget = args.owner.field.widget;
		if (args.owner.field.value() !== null) {
			widget.getField("NRBUTTON").readOnly = false;
			widget.currentRow.NRBUTTON = "";
		}
	};

	this.grupoOnChange = function (args) {
		var field = args.owner.field;
		var widget = field.widget;
		widget.currentRow.NRPGCONFTELA = '';
		field.widget.getField('NRPGCONFTELA').readOnly = field.value() == null || field.value() == '';
		if (field.value() == null || field.value() == '') {
			field.widget.getField('NRPGCONFTELA').value(field.value());
			field.widget.getField('NRBUTTON').value(field.value());
			field.widget.getField('NRBUTTON').readOnly = field.value() == null || field.value() == '';
		}
		widget.currentRow.NRCOLORBACK = this.colorChange(widget.currentRow.NRCOLORBACKGRUPO);
		widget.currentRow.NRCOLORTEXT = this.colorChange(widget.currentRow.NRCOLORTEXTGRUPO);
		templateManager.updateTemplate();
		widget.reload();
	};

	this.filialOnChange = function (args) {
		var field = args.owner.field;
		field.widget.getField('NMCONFTELA').readOnly = field.value() == null || field.value() == '';
		if (field.value() == null || field.value() == '') {
			field.widget.getField('NMCONFTELA').value(field.value());
			field.widget.getField('DSBUTTON').value(field.value());
			field.widget.getField('DSBUTTON').readOnly = field.value() == null || field.value() == '';
			field.widget.getField('NRPGCONFTELA').value(field.value());
			field.widget.getField('NRPGCONFTELA').readOnly = field.value() == null || field.value() == '';
			field.widget.getField('NRBUTTON').value(field.value());
			field.widget.getField('NRBUTTON').readOnly = field.value() == null || field.value() == '';
		}
	};

	this.confgtelaOnChange = function (args) {
		var field = args.owner.field;
		field.widget.getField('DSBUTTON').readOnly = field.value() == null || field.value() == '';
		if (field.value() == null || field.value() == '') {
			field.widget.getField('DSBUTTON').value(field.value());
			field.widget.getField('NRPGCONFTELA').value(field.value());
			field.widget.getField('NRPGCONFTELA').readOnly = field.value() == null || field.value() == '';
			field.widget.getField('NRBUTTON').value(field.value());
			field.widget.getField('NRBUTTON').readOnly = field.value() == null || field.value() == '';
		}
	};

	this.setFilterNRBUTTON = function (field) {
		var row = field.widget.currentRow;
		var dataFilter = field.dataSourceFilter;
		dataFilter[2].value = row.NRCONFTELA;
		dataFilter[3].value = row.IDTPBUTONAUX;
		dataFilter[4].value = row.NRBUTTONAUX;
		dataFilter[5].value = row.NRPGCONFTAUX;
		dataFilter[6].value = row.IDTPBUTONAUX2;
		dataFilter[7].value = row.NRBUTTONAUX2;
		dataFilter[8].value = row.NRPGCONFTELA;
		dataFilter[9].value = row.CDGRUPO;
		dataFilter[10].value = row.PROPRIAPOSICAO;
		field.reload();
	};

	this.productsInsideGroupWidgetSaveAction = function (widget) {
		if (widget.isValid()) {
			widget.currentRow.NRORG = getLocalVar('NRORG');
			widget.currentRow.IDTPBUTONAUX = 2;
			//widget.currentRow.NRBUTTONAUX   = widget.currentRow.NRBUTTON;
			//widget.currentRow.NRPGCONFTAUX  = widget.currentRow.NRPGCONFTELAUX;
			widget.currentRow.CDIDENTBUTON = widget.currentRow.CDPRODUTO;
			widget.currentRow.CDNATPRODUTO = widget.currentRow.CDNATPROD ? widget.currentRow.CDNATPROD : null;
			widget.currentRow.DSMESSAGEBUT = widget.currentRow.DSMESSAGEBUT ? widget.currentRow.DSMESSAGEBUT : null;
			widget.currentRow.DSBUTTON = widget.currentRow.DSBUTTON2;
			widget.currentRow.CDOPERULTATU = getLocalVar('CDOPERADOR');
			widget.currentRow.DSENDEIMG = widget.currentRow.IMAGE;
			if (widget.currentRow.__is_new) {
				widget.currentRow.IDTPBUTONAUX2 = '0';
				widget.currentRow.NRBUTTONAUX2 = '0';
				widget.currentRow.NRPGCONFTAUX2 = '0';
				self.setLocalVarsOnWidget(widget);
				widget.currentRow.CDGRUPO = widget.currentRow.NRPGCONFTELA + "" + widget.currentRow.NRBUTTON;
			}
			var hexBack = ColorPickerController.hexToRgb(widget.currentRow.NRCOLORBACK),
			    hexText = ColorPickerController.hexToRgb(widget.currentRow.NRCOLORTEXT);
			widget.currentRow.NRCOLORBACK = ColorPickerController.RGBToTColor(hexBack.r, hexBack.g, hexBack.b);
			widget.currentRow.NRCOLORTEXT = ColorPickerController.RGBToTColor(hexText.r, hexText.g, hexText.b);

			General.widgetSave(widget).then(function () {

				widget.currentRow.changed = false;
				widget.currentRow.__is_new = false;
				ScreenService.closeSwipe();
				widget.reload();
			});
		}
	};

	this.setLocalVarsOnWidget = function (widget) {
		var row = widget.currentRow;

		row.DTULTATU = moment().format('DD/MM/YYYY HH:mm:ss');
		row.NRORG = getLocalVar('NRORG');
		row.CDOPERULTATU = getLocalVar('CDOPERADOR');
		row.NRORGULTATU = getLocalVar('NRORG');

		if (row.__is_new) {
			row.CDOPERINCLUSAO = getLocalVar('CDOPERADOR');
			row.NRORGINCLUSAO = getLocalVar('NRORG');
			row.DTINCLUSAO = moment().format('DD/MM/YYYY HH:mm:ss');
		}
	};

	this.buildImageInViewMode = function (wdgLogotipo) {
		setTimeout(function () {
			if (!Util.isEmptyOrBlank(wdgLogotipo.currentRow.IMAGE)) {
				var row = wdgLogotipo.currentRow.IMAGE;
				var fieldLogo = $('#span-field-IMAGE');
				var b64Image = (typeof row === 'undefined' ? 'undefined' : _typeof(row)) === "object" ? row[0].b64File : row;
				var urlLogo = b64Image;
				var image = '<img src=' + urlLogo + ' class="img-responsive center-block img-cadEst">';
				if ($('.img-responsive.center-block').length <= 0) {
					fieldLogo.find('img').remove();
					fieldLogo.append(image);
					fieldLogo.find('p').css({ display: 'none' });
				}
			} else {
				this.setDefaultImage();
			}
		}.bind(this), 50);
		wdgLogotipo.redraw();
	};

	this.setDefaultImage = function () {
		var fieldLogo = $('#span-field-IMAGE');
		fieldLogo.find('p').css({ display: 'none' });
		fieldLogo.find('img').remove();
		fieldLogo.append('<img></img>');
		fieldLogo.find('img').addClass('defaultImage');
	};
}

Configuration(function (ContextRegister) {
	ContextRegister.register('LayoutController', LayoutController);
});

// FILE: ./assets/modules/produto/assets/js/controllers/TabelaPrecoController.js
function TabelaPrecoController(ScreenService, General) {

	var MENSAGEM_VALIDA_PRECO = "Os valores de Preço e Preço Subsidiado não podem ter valor menor que zero.";

	var checkValorMenorQueZero = function checkValorMenorQueZero(value) {
		return value < 0;
	};

	this.onChangeFilial = function (args, fieldToReadOnly) {
		var field = args.owner.field;
		var widget = field.widget;

		if (field.value() !== undefined && field.value() != '') {
			widget.getField(fieldToReadOnly).readOnly = false;
		} else {
			widget.getField(fieldToReadOnly).readOnly = true;
			widget.getField(fieldToReadOnly).value(null);
		}
		widget.getField(fieldToReadOnly).value(null);
	};

	this.newPriceTag = function (args) {
		var widget = args.owner.widget;
		General.widgetNewRow(widget);
		widget.currentRow.NMPRODUTO = General.getFieldValue('NMPRODUTO', 'Detalhamento');
		widget.currentRow.CDPRODUTO = General.getFieldValue('CDPRODUTO', 'Detalhamento');
		widget.currentRow.CDARVPROD = General.getFieldValue('CDARVPROD', 'Detalhamento');
		if (Array.isArray(widget.appliedFilter) && widget.appliedFilter.FILTER_ROW.CDFILIAL !== undefined && widget.appliedFilter.FILTER_ROW.CDFILIAL !== '' && widget.appliedFilter.FILTER_ROW.CDFILIAL !== null) {
			widget.currentRow.CDFILIAL = widget.appliedFilter.FILTER_ROW.CDFILIAL;
		}
		widget.getField('CDFILIAL').readOnly = false;
		widget.getField('CDTABEPREC').readOnly = false;
		widget.reload();
	};

	this.parseStrToFloat = function (value) {
		if (!!value) {
			value = String(value);
			var numberOfDots = (value.match(/\./g) || []).length,
			    hasVirgula = !!(value.match(/\,/g) || []).length;

			if (hasVirgula) {
				if (!!numberOfDots) {
					value = value.replace(/\./g, "");
				}

				value = value.replace(",", ".");
			}
		} else {
			value = 0.00;
		}

		return parseFloat(value);
	};

	this.savePriceTag = function (widget) {
		widget.currentRow.NRORG = getLocalVar('NRORG');
		widget.currentRow.CDPRODUTO = General.getFieldValue('CDPRODUTO', 'Detalhamento');
		widget.currentRow.CDPRPAITABPR = General.getFieldValue('CDPRODUTO', 'Detalhamento');
		widget.currentRow.VRPRECITEM = this.parseStrToFloat(widget.currentRow.VRPRECITEM);
		widget.currentRow.VRPRESUGITEM = this.parseStrToFloat(widget.currentRow.VRPRESUGITEM);
		widget.currentRow.VRPRECITEMCL = this.parseStrToFloat(widget.currentRow.VRPRECITEMCL);
		widget.currentRow.VRCUSTITEM = this.parseStrToFloat(widget.currentRow.VRCUSTITEM);
		General.widgetSave(widget).then(function () {
			ScreenService.closeSwipe();
			widget.reload();
		});
	};

	this.editPriceTag = function (args) {
		var widget = args.owner.widget;
		General.widgetEdit(widget);
		var CurrentRow = widget.currentRow;
		CurrentRow.CDFILIAL = Array.isArray(CurrentRow.CDFILIAL) ? CurrentRow.CDFILIAL : [CurrentRow.CDFILIAL];
		CurrentRow.CDTABEPREC = Array.isArray(CurrentRow.CDTABEPREC) ? CurrentRow.CDTABEPREC : [CurrentRow.CDTABEPREC];
		CurrentRow.NMTABEPREC = Array.isArray(CurrentRow.NMTABEPREC) ? CurrentRow.NMTABEPREC : [CurrentRow.NMTABEPREC];
		CurrentRow.CDFILIALTAB = Array.isArray(CurrentRow.CDFILIAL) ? CurrentRow.CDFILIAL : [CurrentRow.CDFILIAL];
		CurrentRow.DTFINVGPREC = Array.isArray(CurrentRow.DTFINVGPREC) ? CurrentRow.DTFINVGPREC : [CurrentRow.DTFINVGPREC];
		CurrentRow.DTINIVGPREC = Array.isArray(CurrentRow.DTINIVGPREC) ? CurrentRow.DTINIVGPREC : [CurrentRow.DTINIVGPREC];
		widget.getField('CDFILIAL').reload();
		widget.getField('CDTABEPREC').reload();
	};
}

Configuration(function (ContextRegister) {
	ContextRegister.register('TabelaPrecoController', TabelaPrecoController);
});

// FILE: ./assets/modules/produto/assets/js/controllers/ger01900_cadastroproduto_controller.js
var ger01900_cadastroproduto_controller = function ger01900_cadastroproduto_controller(ZhUtil, ScreenService, templateManager, General, ProcProdWorkflowService, ProdutoService, ZhFilterPreferences, restEngine, MessageService) {

	var ignoredKeys = ["__rightActions", "__leftActions", "_children", "_parent", "__groupHeaders", "__index", "__isSelected", "__notSelectable", "$$hashKey", "$error"];

	this.setDynamicRequiredFields = function (mainWidget) {
		General.callRestEngine('cadEst#/crud/paramgeral', 'FilterData', []).then(function (success) {
			if (success.dataset.paramgeral.length) {
				var paramgeral = success.dataset.paramgeral[0];
				var obrigaNCM = paramgeral.IDOBRNCMCADPR == 'S' ? true : false;
				var widgetFiscal = templateManager.container.getWidget('Fiscal');
				var fieldNCM = widgetFiscal.getField('CDCLASFISC');
				if (obrigaNCM) fieldNCM.validations = { "required": { "message": "Campo Obrigatorio" } };else delete fieldNCM.validations.required;
			}
		});
	};

	this.openFilterWidget = function (widget) {

		var defaultFilter = Util.clone(widget.currentRow);

		defaultFilter.IDPRODATIVPR = 'S';

		ZhFilterPreferences.setOriginalFilter(widget.id, defaultFilter);
		ZhFilterPreferences.openFilterWidget(widget, defaultFilter);
	};

	this.allRulesWidgets = function () {
		this.rulesToCardapio(templateManager.container.getWidget('Cardapio'));
		this.rulesToCatering(templateManager.container.getWidget('Catering'));
		this.rulesToEstoque(templateManager.container.getWidget('Estoque'));
		this.rulesToProducao(templateManager.container.getWidget('Produção'));
	};

	this.allWidgetsToView = function () {
		var widget = templateManager.container.getWidget('produtos2');
		widget.view();
		widget.getParent().list();
		widget.widgets.forEach(function (widget) {
			widget.view();
			widget.template = widget.templateToView;
		});
	};

	this.afterChange = function (widget) {
		var mainWidget = widget.getParent();
		mainWidget.widgets.forEach(function (widget) {
			widget.enabled = true;
		});
		templateManager.container.getWidget('arvsprod').enabled = true;
		templateManager.container.getWidget('vendas').enabled = true;

		widget.template = widget.templateToView;
		widget.view();
		mainWidget.view();
	};

	this.callSave = function (widget, route) {
		ScreenService.showLoader();
		var row = Util.clone(widget.currentRow, ignoredKeys);
		row.DEBUGMODE = false;
		General.callRestEngine(route, 'Row', row).then(function (result) {
			var currentProduct = result.dataset.produto[0];
			widget.currentRow = currentProduct;
			var widgetPrincipal = widget.container.getWidget('produtos');
			widgetPrincipal.currentRow = currentProduct;
			this.updateWidgets(widget.currentRow);
			this.allWidgetsToView();
			this.updateProductInMainWidget();
			this.afterChange(widget);
			if (result.messages) {
				ScreenService.alertNotification(result.messages[0].message);
			}
			ScreenService.hideLoader();
		}.bind(this), this.errorRequest);
	};

	this.cancelEdit = function (widget) {
		var __is_new = angular.copy(widget.currentRow.__is_new);

		this.afterChange(widget);

		widget.currentRow = widget.backupRow;

		if (__is_new) {
			ScreenService.closeSwipe();
			widget.getParent().getParent().dataSource.data.pop();
		}
	};

	this.deleteGroupTree = function (widget) {
		ScreenService.confirmMessage(ScreenService.i18n('Delete Register?'), 'question', function (success) {
			General.callRestEngine('cadEst_produto#/crud/prodarvoreprod/remove', 'Row', widget.currentRow).then(function () {
				ScreenService.closeSwipe().then(function () {
					widget.activate();
					widget.reload();
				});
			}, this.errorRequest);
		}.bind(this));
	};

	this.editMode = function (widgetEditing, skipeEnabled) {
		var nameSkip = widgetEditing.name;
		var mainWidget = widgetEditing.getParent();

		if (!skipeEnabled) {
			mainWidget.widgets.forEach(function (widget) {
				if (widget.name !== nameSkip) {
					widget.enabled = false;
				}
			});
		}

		templateManager.container.getWidget('arvsprod').enabled = false;
		templateManager.container.getWidget('vendas').enabled = false;
		var rowBackup = Util.clone(widgetEditing.currentRow, ignoredKeys);
		widgetEditing.backupRow = rowBackup;
		widgetEditing.template = widgetEditing.templateToForm;
		mainWidget.edit();
		widgetEditing.edit();
		ScreenService.showLoader();
		setTimeout(function (time) {
			widgetEditing.currentRow = rowBackup;
			ScreenService.hideLoader();
		}, 1000);
	};

	this.errorRequest = function (error) {
		if (error.data.error) {
			ScreenService.showMessage(error.data.error);
		} else {
			ScreenService.showMessage(error);
		}
		ScreenService.hideLoader();
	};

	this.gerFilterForPrductComplete = function () {
		var levels = General.getLevelByMask('GER_CDPICTPROD', 1);

		return levels.length;
	};

	this.getMaskPenulLevel = function () {
		var mask = getLocalVar('GER_CDPICTPROD');
		mask = mask.split('.');
		mask.pop();
		return mask.join('.');
	};

	this.grupFieldReadOnly = function () {
		var widget = templateManager.container.getWidget('arvsprod');
		var field = widget.getField('NMARVOREPROD');
		field.readOnly = true;
	};

	this.newRelacTreeeProd = function (widget) {
		widget.newRow();
		widget.currentRow.CDPRODUTO = widget.getParent().currentRow.CDPRODUTO;
	};

	this.isProductStock = function () {
		var widget = templateManager.container.getActiveWidget();
		var indent = widget.currentRow.IDESTOCOMP;
		if (indent === 'E') {
			return true;
		} else {
			return false;
		}
	};

	this.rulesItemGenero = function (widget) {
		if (widget.currentRow.CDTPITEMPROD || widget.currentRow.CDGENPROD) {
			widget.getField('DSGENPROD').validations.required = true;
			widget.getField('NMTPITEMPROD').validations.required = true;
		} else {
			delete widget.getField('DSGENPROD').validations.required;
			delete widget.getField('NMTPITEMPROD').validations.required;
		}
	};

	this.removeHintFields = function (widgets) {
		if (!Array.isArray(widgets)) {
			widgets = [widgets];
		}

		widgets.forEach(function (widget) {
			delete widget.currentRow.$error;
		});
	};

	this.rulesSelectClasfiscal = function (widget) {
		var clasfiscal = widget.currentRow.CDCLASFISC;
		var genero = clasfiscal.substr(0, 2);
		var filter = [{
			"name": "CDGENPROD",
			"operator": "=",
			"value": genero
		}];
		General.callRestEngine('cadEst_produto#/crud/generoprod_livromagnetico', 'FilterData', filter).then(function (data) {
			data = data.dataset.generoprod_livromagnetico;
			if (data.length > 0) {
				widget.currentRow.CDGENPROD = data[0].CDGENPROD;
				widget.currentRow.DSGENPROD = data[0].DSGENPROD;
			} else {
				widget.currentRow.CDGENPROD = null;
				widget.currentRow.DSGENPROD = null;
			}
			this.rulesItemGenero(widget);
		}.bind(this), this.errorRequest);
	};

	this.validaFatoConv = function (widget) {
		var fieldFatoConv = widget.container.getWidget('Estoque').getField('VRFATOCONV');
		if (this.isProductStock()) {
			fieldFatoConv.setValue(1);
			widget.currentRow.VRFATOCONV = 1;
		} else {
			if (fieldFatoConv.value() <= 0) {
				fieldFatoConv.setValue(null);
				ScreenService.showMessage('Favor de conversão deve ser maior que 0');
			}
		}
	};

	this.rulesToCardapio = function (widget) {
		if (this.isProductStock()) {
			widget.getField('VRARREDREQ').readOnly = false;
		} else {
			widget.getField('VRARREDREQ').readOnly = true;
		}
	};

	this.rulesToCatering = function (widget) {
		if (this.isProductStock()) {
			widget.getField('DSVRYIELD').readOnly = false;
			widget.getField('DSVRYIELD').validations.required = true;
		} else {
			widget.getField('DSVRYIELD').readOnly = true;
			delete widget.getField('DSVRYIELD').validations.required;
		}
	};

	this.rulesToEstoque = function (widget) {
		if (this.isProductStock()) {
			widget.getField('VRPESOUNID').readOnly = false;
			widget.getField('DSPEFATOCORR').readOnly = false;
			widget.getField('DSPEFATOCORR').validations.required = true;
			widget.getField('NMPRODESTO').readOnly = true;
			delete widget.getField('NMPRODESTO').validations.required;
			widget.getField('VRFATOCONV').readOnly = true;
			delete widget.getField('VRFATOCONV').validations.required;
		} else {
			widget.getField('VRPESOUNID').readOnly = true;
			widget.getField('DSPEFATOCORR').readOnly = true;
			delete widget.getField('DSPEFATOCORR').validations.required;
			widget.getField('NMPRODESTO').readOnly = false;
			widget.getField('NMPRODESTO').validations.required = true;
			widget.getField('VRFATOCONV').readOnly = false;
			widget.getField('VRFATOCONV').validations.required = true;
		}
	};

	this.rulesToMoveRow = function (mainWidget) {
		ScreenService.showLoader();
		mainWidget.widgets[0].activate().then(function () {
			if (mainWidget.currentRow.__is_new) {
				this.rulesToInsert(mainWidget);
			} else {
				this.getCorrecao(mainWidget);
				this.allWidgetsToView();
				this.updateWidgets(mainWidget.currentRow);
				ScreenService.hideLoader();
				templateManager.container.getWidget('Detalhamento').activate();
				templateManager.container.getWidget('Detalhamento').redraw();
				mainWidget.openTab('produtos2');
				/*				mainWidget.widgets[0].activate().then(function() {
    					mainWidget.widgets[0].widgets[0].activate().then(function() {
    						mainWidget.widgets[0].widgets[0].activate();
    						ScreenService.hideLoader();
    					});
    				});*/
			}
		}.bind(this));
		templateManager.container.getWidget('impostos').openFilter = true;
	};

	this.rulesToInsert = function (mainWidget) {
		var widget = mainWidget.widgets[0];
		General.callRestEngine('cadEst#/crud/paramplaneja', 'FilterData', []).then(function (data) {
			data = data.dataset.paramplaneja[0];
			widget.widgets.forEach(function (widgetChild) {
				this.editMode(widgetChild, true);
				widgetChild.currentRow.__is_new = true;
				widgetChild.currentRow.NRCORSAFRA = data ? data.NRCORSAFRA : null;
				widgetChild.currentRow.NRCORINICSAF = data ? data.NRCORINICSAF : null;
				widgetChild.currentRow.NRCORENTRSAF = data ? data.NRCORENTRSAF : null;
				widgetChild.applyDefaultValue();
			}.bind(this));
			widget.activate();
			ScreenService.hideLoader();
		}.bind(this), this.errorRequest);
	};

	this.rulesToProducao = function (widget) {
		if (this.isProductStock()) {
			widget.getField('NMPRODPROD').readOnly = false;
			widget.getField('VRFATOCONVPR').readOnly = false;
			widget.getField('IDPRODPROD').readOnly = false;
		} else {
			widget.getField('NMPRODPROD').readOnly = true;
			widget.getField('VRFATOCONVPR').readOnly = true;
			widget.getField('IDPRODPROD').readOnly = true;
		}
		this.ruleToProdProducao(widget);
	};

	this.ruleToProdProducao = function (widget) {
		if (widget.currentRow.CDPRODPROD) {
			widget.getField('VRFATOCONVPR').validations.required = true;
		} else {
			delete widget.getField('VRFATOCONVPR').validations.required;
		}
	};

	this.rulesTreeGroup = function (widget) {
		var currentRow = widget.currentRow;
		var groupField = widget.getField('NMARVOREPROD');

		if (currentRow.NRTPARVPROD) {
			groupField.dataSourceFilter[0].value = currentRow.NRTPARVPROD;
			groupField.readOnly = false;
			groupField.reload();
		} else {
			groupField.readOnly = true;
		}
	};

	this.save = function (widget) {
		this.validaFatoConv(widget);
		this.setCorrecao(widget);
		if (widget.currentRow.__is_new) {
			this.saveNew(widget);
		} else if (widget.isValid()) {
			this.callSave(widget, 'cadEst_produto#/saveProduct');
		}
	};

	this.saveNew = function (widget) {
		var save = true;
		var widgets = widget.getParent().widgets;

		for (var index = 0; index < widgets.length; index++) {
			var widgetChild = widgets[index];
			var activateWidget = function activateWidget() {
				this.activate();
			};

			if (!widgetChild.isValid()) {
				widgetChild.activate().then(activateWidget.bind(widgetChild));
				save = false;
				index = widgets.length;
			}
		}

		if (save) {
			this.callSave(widget, 'cadEst_produto#/saveProduct');
		}
	};

	this.saveFiscal = function (widget) {
		if (widget.currentRow.__is_new) {
			this.save(widget);
		} else if (widget.isValid()) {
			this.callSave(widget, 'cadEst_produto#/saveAbaFiscal');
		}
	};

	this.saveProdutoArvoreProduto = function (widget) {
		if (widget.isValid()) {
			var row = widget.currentRow;
			General.callRestEngine('cadEst_produto#/arvoreprodtree/save', 'Row', row).then(function (success) {
				widget.view();
				ScreenService.closeSwipe();
				widget.getField('NMARVOREPROD').readOnly = true;
			}, this.errorRequest);
		}
	};

	this.getCorrecao = function (widget) {
		var currentRow = widget.currentRow;
		if (currentRow.VRPEFATOCORR != null) {
			var vrpefatocorr = parseFloat(currentRow.VRPEFATOCORR);
			var dspefatocorr = 1 + vrpefatocorr / 100;
			var dsvryield = 100 - vrpefatocorr;
			widget.currentRow.DSPEFATOCORR = dspefatocorr;
			widget.currentRow.DSVRYIELD = dsvryield;
		}
	};

	this.setCorrecao = function (widget) {
		var currentRow = widget.currentRow;

		if (currentRow.DSPEFATOCORR != null) {
			currentRow.DSPEFATOCORR = String(currentRow.DSPEFATOCORR).replace(',', '.');
			var dspefatocorr = parseFloat(currentRow.DSPEFATOCORR);
			if (dspefatocorr >= 1 && dspefatocorr < 2) {
				dspefatocorr = (dspefatocorr - 1) * 100;
				var dsvryield = 100 - dspefatocorr;
				currentRow.VRPEFATOCORR = dspefatocorr;
				widget.currentRow.DSVRYIELD = dsvryield;
			} else {
				if (currentRow.CDPRODESTO == currentRow.CDPRODUTO) ScreenService.showMessage('Fator de correção deve estar entre 1,00 e 1,99.');
				currentRow.DSPEFATOCORR = null;
			}
		}
	};

	this.setVrpefatocorr = function (currentRow) {
		var dsvryield = parseInt(currentRow.DSVRYIELD);
		if (dsvryield >= 1 && dsvryield <= 100) {
			currentRow.DSPEFATOCORR = 1 + (100 - dsvryield) / 100;
			currentRow.VRPEFATOCORR = 100 - dsvryield;
		} else {
			currentRow.DSVRYIELD = null;
			currentRow.VRPEFATOCORR = null;
			currentRow.DSPEFATOCORR = null;
			ScreenService.showMessage('O YIELD deve ser de 1 até 100');
		}
	};

	this.setVrYield = function (currentRow) {
		var dspefatocorr = currentRow.DSPEFATOCORR;
		if (dspefatocorr < 2 && dspefatocorr > 0.99) {
			currentRow.DSVRYIELD = (2 - dspefatocorr) * 100;
			dspefatocorr = parseInt((dspefatocorr - 1) * 100);
			currentRow.VRPEFATOCORR = dspefatocorr;
		} else {
			currentRow.DSVRYIELD = null;
			currentRow.VRPEFATOCORR = null;
			currentRow.DSPEFATOCORR = null;
			ScreenService.showMessage('O Fator de Correção deve ser de 1,0 até 1,99');
		}
	};

	this.sugestedArvprod = function (widget) {
		var prodnivante = widget.currentRow.CDARVPRODNIVANTE;
		var nvprodnivante = widget.currentRow.CDNVPRODNIVANTE;
		var rigthLevel = General.getLevelByMask('GER_CDPICTPROD', 1).length - 1;
		if (nvprodnivante && nvprodnivante != rigthLevel) {
			ScreenService.showMessage('Produto selecionado inválido. Só é permitido selecionar produtos de nível ' + rigthLevel + '.');

			/* MSG NOVA */
			var variaveis = {
				NIVELCOMPLETO: rigthLevel
			};

			MessageService.showMessageByCode("NIVELMAXPROD", variaveis, { "type": "error" });
			/* FIM MSG NOVA */

			widget.currentRow.CDPRODNIVANTE = null;
			widget.currentRow.CDARVPRODNIVANTE = null;
			widget.currentRow.CDNVPRODNIVANTE = null;
		} else if (nvprodnivante) {
			var row = {
				'PARENTCDPRODUTO': prodnivante,
				'PARENTNVPRODUTO': nvprodnivante
			};
			if (!widget.currentRow.CDARVPROD) {
				General.callRestEngine('cadEst_produto#/sugestedArvprod', 'Row', row).then(function (request) {
					var sugested = request.dataset.sugestedArvprod[0];
					widget.currentRow.CDARVPROD = sugested.CDDARVPROD;
				}.bind(this), this.errorRequest);
			}
		}
	};

	this.updateProductInMainWidget = function () {
		templateManager.container.getWidget('produtos').reload();
	};

	this.updateWidgets = function (valueToUpdate) {
		var widget = templateManager.container.getWidget('produtos2');
		valueToUpdate = Util.clone(valueToUpdate, ignoredKeys);
		widget.widgets.forEach(function (widget) {
			widget.currentRow = valueToUpdate;
		});
	};

	this.updateWidgetsIfAdding = function (widget) {
		if (widget.currentRow.__is_new) {
			this.updateWidgets(widget.currentRow);
		}
	};

	this.validateTpTree = function (widget) {
		var row = widget.currentRow;
		if (!row.NRARVOREPRODPAI) {
			delete row.NMTPARVORE;
			delete row.NRARVOREPROD;
			delete row.NRTPARVPROD;
			delete row.NMARVOREPROD;
			ScreenService.showMessage('Não é possível escolher o primeiro nível do Agrupamento de Produto.');
		}
	};

	this.deleteProduct = function (widget) {
		var row = Util.clone(widget.currentRow, ignoredKeys);
		row.DEBUGMODE = false;
		General.callRestEngine('cadEst#/deleteProduct', 'Row', row).then(function (result) {
			if (isset(function () {
				return result.messages;
			})) {
				ScreenService.showMessage(result.messages[0].message);
			} else {
				widget.getParent().getParent().reload();
				ScreenService.closeSwipe();
			}
		});
	};

	this.newProduto = function (widget) {
		var detalhamento = widget.container.getWidget('Detalhamento');
		var codArvore = detalhamento.getField('CDARVPRODNIVANTE');
		widget.newRow();
		codArvore.dataSource.load();
	};

	this.LoadCodArvore = function (widget) {
		var nivelProd = widget.getField('CDARVPRODNIVANTE');
		var fieldTpProduto = widget.getField('IDESTOCOMP');
		nivelProd.dataSource.load();
		var data = nivelProd.dataSource.data;

		if (data.length === 0) {
			delete nivelProd.validations.required;
			fieldTpProduto.readOnly = false;
		} else {
			nivelProd.validations.required = true;
			fieldTpProduto.readOnly = true;
		}
	};

	this.validaFator = function (widget) {
		var currentRow = widget.currentRow;
		if (currentRow.VRFATOCONV <= 0) {
			ScreenService.showMessage('Fator de Conversão deve ser maior que 0.');
			currentRow.VRFATOCONV = "";
		}
	};

	this.validateProductPermissions = function (widget) {
		var cdnvarvore = widget.currentRow.CDARVPRODNIVANTE;
		var fieldTpProduto = widget.getField('IDESTOCOMP');
		var filter = [{
			"name": "P_CDPRODUTO",
			"operator": "=",
			"value": cdnvarvore
		}, {
			"name": "CDOPERADOR",
			"operator": "=",
			"value": "OPERADOR_LOGADO"
		}];
		General.callRestEngine('cadEst#/crud/gropernvprod_operador', 'FilterData', filter).then(function (response) {
			if (response.dataset.gropernvprod_operador[0]) {
				var resultRow = response.dataset.gropernvprod_operador[0];
				if (resultRow.IDPERMINCPRODEST == 'S') fieldTpProduto.readOnly = false;else {
					fieldTpProduto.readOnly = true;
					widget.currentRow.IDESTOCOMP = 'C';
				}
			} else {
				fieldTpProduto.readOnly = false;
			}
		});
	};

	this.setStockProductFilter = function (args) {
		var field = args.owner.field;
		var valueToFilter = General.getFieldValue('CDARVPRODNIVANTE', 'Detalhamento');
		valueToFilter = valueToFilter ? valueToFilter + '%' : '%%';

		field.dataSourceFilter[0].value = valueToFilter;
	};

	this.openPopupCodBar = function () {
		var widPopupCod = templateManager.container.getWidget('popUpCodigoBarra');
		var widgetProduto = templateManager.container.getWidget('produtos');
		var nomeProd = widgetProduto.currentRow.NMPRODUTO;
		widPopupCod.label = 'Codigos de Barra - ' + nomeProd;
		ScreenService.openPopup(widPopupCod);
	};

	this.saveCodeBars = function (args) {
		var rows = args.dataSource;
		var parent = args.owner.getParent().getWidget('produtos');
		var codprod = parent.currentRow.CDPRODUTO;
		rows.forEach(function (row) {
			if (row.__is_new) {
				row.CDPRODUTO = codprod;
				delete row.__leftActions;
				delete row.__rightActions;
			}
		});
		var edited = rows.some(function (row) {
			return row.changed && !row.__is_new;
		});
		if (edited) ScreenService.showMessage('Para alterar o registro deve ser excluído e adicionado novamente.');
		var rowsToSave = rows.filter(function (row) {
			return row.__is_new;
		});
		return saveDataset('cadEst#/crud/cdbarraprod/save', rowsToSave).then(function (success) {
			args.owner.reload();
			args.owner.cancelActionClick();
		}, function (error) {
			ScreenService.showMessage(error.data.error);
			args.owner.cancelActionClick();
		});
	};

	var saveDataset = function saveDataset(dataSourceName, dataToSave) {
		var otherParams = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

		return restEngine.post(dataSourceName, Util.extend({
			"requestType": "DataSet",
			"dataset": dataToSave
		}, otherParams || {}), undefined, undefined, undefined, undefined, 8001000);
	};

	this.newCodeBar = function (widget) {
		General.widgetNewRow(widget);
	};

	this.deleteCodeBar = function (args) {
		var widget = args.owner.widget;
		General.deleteCrud(widget).then(function () {
			return widget.reload();
		});
	};

	this.productFieldFilterHandler = function (field) {
		var widget = field.widget;
		var fieldProdIni = widget.getField('NMPRODINI');
		var fieldProdFim = widget.getField('NMPRODFIN');

		switch (field.name) {
			case "NMPRODINI":
				if (fieldProdIni.value() !== "") {
					fieldProdIni.validations = { "required": true };
					fieldProdFim.validations = { "required": true };
					fieldProdFim.readOnly = false;
				} else {
					widget.currentRow.NMPRODINI = '';
					widget.currentRow.NMPRODFIN = '';
					widget.currentRow.CDPRODINI = '';
					widget.currentRow.CDPRODFIN = '';
					delete fieldProdIni.validations;
					delete fieldProdFim.validations;
					fieldProdFim.readOnly = true;
				}
				break;

			case "NMPRODFIN":
				if (widget.currentRow.NMPRODINI === '' && widget.currentRow.NMPRODFIN === '') {
					delete fieldProdIni.validations;
					delete fieldProdFim.validations;
					fieldProdFim.readOnly = true;
				}
				break;
			default:
				return;
		}
		this.checkProductRange(field);
	};

	this.checkProductRange = function (field) {
		var currentRow = field.widget.currentRow;

		if (currentRow.CDPRODINI && currentRow.CDPRODFIN) {
			var compproduto = currentRow.CDPRODFIN ? currentRow.CDPRODFIN.replace(/[\.\-]/g, '') : '';

			if (!General.comparaPratoProduto(currentRow.CDPRODINI, compproduto, getLocalVar('CDPICTPROD'))) {
				currentRow[field.outData[field.descriptionField]] = '';
				currentRow[field.outData[field.valueField]] = '';

				ScreenService.showMessage("O Produto Final não pode ser maior que o Produto Inicial.");
			}
		}
	};

	var isset = function isset(accessor) {
		try {
			// Note we're seeing if the returned value of our function is not
			// undefined
			return typeof accessor() !== 'undefined' && accessor() !== null;
		} catch (e) {
			// And we're able to catch the Error it would normally throw for
			// referencing a property of undefined
			return false;
		}
	};
};

Configuration(function (ContextRegister, eventEngine) {
	ContextRegister.register('ger01900_cadastroproduto_controller', ger01900_cadastroproduto_controller);
});

// FILE: ./assets/modules/produto/assets/js/controllers/ger01900_relatoriocustomizavelproduto_controller.js
function ger01900_relatoriocustomizavelproduto_controller(ZhFilterPreferences, ScreenService, General, templateManager, localStorageEngine) {

	this.enableDisableData = function (widget) {
		var PARAM = widget.currentRow.PARAM;

		if (PARAM == 'D') {
			widget.getField('NRDIAS').readOnly = false;
			widget.getField('DATAINI').readOnly = true;
			widget.getField('DATAFIN').readOnly = true;

			widget.getField('NRDIAS').validations = { "min": { "limit": 1 }, "max": { "value": 999 } };
			widget.getField('DATAINI').validations = {};
			widget.getField('DATAFIN').validations = {};
		} else if (PARAM == 'P') {
			widget.getField('NRDIAS').readOnly = true;
			widget.getField('DATAINI').readOnly = false;
			widget.getField('DATAFIN').readOnly = false;

			widget.getField('NRDIAS').validations = {};
			widget.getField('DATAINI').validations = { "required": true };
			widget.getField('DATAFIN').validations = { "required": true };
		}

		widget.getField('NRDIAS').reload();
		widget.getField('DATAINI').reload();
		widget.getField('DATAFIN').reload();
	};

	this.openFilter = function (widget) {
		var rowsToSet = {};

		var levels = General.getLevelByMask("GER_CDPICTPROD", 1);
		var nivelField = widget.getField("NIVEL");
		var data = [];
		levels.forEach(function (level) {
			data.push({ value: level.nivel, description: level.nivel });
		});

		nivelField.dataSource.data = data;
		rowsToSet.TIPODEORDENACAO = 'CODIGO';
		rowsToSet.NIVEL = String(data.length);
		rowsToSet.TPLISTPROD = '2';

		ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(function () {
			// templateManager.container.getActiveWidget().getAction('close').isVisible = false;
			// this.changeFilial(widget);
		}.bind(this));
	};

	this.habilitaNvOrdenacao = function (args) {
		var widget = args.owner.field.widget;
		if (widget.getField('TIPODEORDENACAO').value() == 'NOME') {
			templateManager.container.getWidget('produtos').order = ["NMPRODUTO"];
			widget.getField('NIVEL').readOnly = false;
			widget.getField('TPLISTPROD').readOnly = true;
			widget.getField('TPLISTPROD').value(String(2));

			templateManager.container.getWidget('produtos').dataSource.name = "cadEst#/crud/customizavel_produto_completa_alfabetica";
			templateManager.container.getWidget('produtos').floatingControl.xlsAction.dataSourceName = "customizavel_produto_completa_alfabetica";
		} else {
			templateManager.container.getWidget('produtos').order = ["CDARVPROD"];
			var tam = widget.getField('NIVEL').dataSource.data.length;
			widget.getField('NIVEL').readOnly = true;
			widget.getField('NIVEL').value(String(tam));
			widget.getField('TPLISTPROD').readOnly = false;

			templateManager.container.getWidget('produtos').dataSource.name = "cadEst#/crud/customizavel_produto_completa";
			templateManager.container.getWidget('produtos').floatingControl.xlsAction.dataSourceName = "customizavel_produto_completa";
		}
	};

	this.getFilialLogada = function () {
		var filter = [{
			"name": "CDFILIAL",
			"operator": "=",
			"value": "FILIAL_LOGADA"
		}];
		return General.callRestEngine('est#/crud/filial', 'FilterData', filter);
	};

	//Parâmetros Filtro da Widget
	this.changeFilter = function (widget, preference) {
		var filterRow = preference.FILTER_ROW;
		var filtro = [];

		var mascara = 20 - filterRow.CDARVPRODFIN.length;
		var produtoFinal = filterRow.CDARVPRODFIN + 'z'.repeat(mascara).substring(0, mascara);

		filtro = [{
			"name": "P_PRODINI",
			"operator": "=",
			"value": filterRow.CDARVPRODINI ? filterRow.CDARVPRODINI : null
		}, {
			"name": "P_PRODFIM",
			"operator": "=",
			"value": produtoFinal
		}, {
			"name": "P_NIVEL",
			"operator": "=",
			"value": filterRow.NIVEL
		}, {
			"name": "P_TPLISTPROD",
			"operator": "=",
			"value": filterRow.TPLISTPROD
		}];

		widget.dataSourceFilter = filtro;
		widget.reload();
	};

	this.changeFilterLancEstoq = function (args) {
		var cdfilial = args.owner.field.widget.currentRow.CDFILIAL;
		var dtlancestq = args.owner.field.widget.currentRow.DTLANCESTQ;
		args.owner.field.widget.getField('NRLANCESTQ').dataSourceFilter[0].value = cdfilial;
		args.owner.field.widget.getField('NRLANCESTQ').dataSourceFilter[1].value = dtlancestq;
		if (dtlancestq != "") {
			args.owner.field.widget.getField('NRLANCESTQ').reload();
			templateManager.container.getWidget('EmissaoInventarioGrid').dataSource.name = "est_relatorios#/crud/itlanctoest_produto";
		} else {
			templateManager.container.getWidget('EmissaoInventarioGrid').dataSource.name = "est_relatorios#/produto_posestatu_paramfilial";
		}
	};

	this.changeFilterLancEstoqByFilial = function (args) {
		var cdfilial = args.owner.field.widget.currentRow.CDFILIAL;
		var dtlancestq = args.owner.field.widget.currentRow.DTLANCESTQ;

		args.owner.field.widget.getField('NRLANCESTQ').dataSourceFilter[0].value = cdfilial;
		args.owner.field.widget.getField('NRLANCESTQ').dataSourceFilter[1].value = dtlancestq;
		args.owner.field.widget.currentRow.NRLANCESTQ = "";
		if (dtlancestq != "") {
			args.owner.field.widget.getField('NRLANCESTQ').reload();
			templateManager.container.getWidget('EmissaoInventarioGrid').dataSource.name = "est_relatorios#/crud/itlanctoest_produto";
		} else {
			templateManager.container.getWidget('EmissaoInventarioGrid').dataSource.name = "est_relatorios#/produto_posestatu_paramfilial";
		}
	};
}

Configuration(function (ContextRegister) {
	ContextRegister.register('ger01900_relatoriocustomizavelproduto_controller', ger01900_relatoriocustomizavelproduto_controller);
});

// FILE: ./assets/modules/produto/assets/js/controllers/ger01901_cadastrotipoarvoreproduto_controller.js
var ger01901_cadastrotipoarvoreproduto_controller = function ger01901_cadastrotipoarvoreproduto_controller(ScreenService, General) {

	var G_NRARVPRODPAI;
	var G_NMARVPRODPAI;
	var G_NRTPARVPRODPAI;

	this.desabilitaEHabilitaEstrutura = function (widget) {
		widget.container.getWidget("estrutura").getParent().activate();
		widget.container.getWidget("estrutura").isVisible = true;
	};

	this.filtroParaNivelPai = function (widget) {
		var field = widget.getField('NMARVOREPRODPAI');
		if (typeof widget.currentRow.NRARVOREPROD !== "undefined") {
			field.dataSourceFilter.push({
				"name": "NRARVOREPROD",
				"operator": "<>",
				"value": widget.currentRow.NRARVOREPROD
			});
		}
		field.reload();
	};

	this.getArvProdPai = function (widget) {
		G_NRARVPRODPAI = widget.currentRow.NRARVOREPROD;
		G_NMARVPRODPAI = widget.currentRow.NMARVOREPROD;
	};

	this.novoItemEstrutura = function (widget) {
		var novoNrarvoreprodpai;
		var novoNmarvoreprodpai;
		if (widget.mode === "view") {
			novoNrarvoreprodpai = typeof widget.currentRow.NRARVOREPROD !== "undefined" ? widget.currentRow.NRARVOREPROD : null;
			novoNmarvoreprodpai = typeof widget.currentRow.NMARVOREPROD !== "undefined" ? widget.currentRow.NMARVOREPROD : null;
		} else {
			novoNrarvoreprodpai = null;
			novoNmarvoreprodpai = null;
		}

		widget.edit();
		widget.newRow();
		widget.getField('NMARVOREPRODPAI').setValue(novoNmarvoreprodpai);
		widget.currentRow.NRARVOREPRODPAI = novoNrarvoreprodpai;
		widget.currentRow.NRTPARVPRODPAI = widget.currentRow.NRTPARVPROD;
	};

	this.novoTipoArvore = function (widget) {
		widget.newRow();
	};

	this.onEnterEstrutura = function (widget) {
		if (widget.mode == "list") {
			widget.reload();
		}
	};

	this.onEnterTabEstrutura = function (widget) {
		var nrtparvprod = widget.container.getWidget('tipoarvoreproduto').currentRow.NRTPARVPROD;

		var filter = [{
			"name": "NRTPARVPROD",
			"operator": "=",
			"value": nrtparvprod
		}];

		widget.dataSourceFilter = filter;
	};

	this.onEnterTabTipoArvore = function (widget) {
		if (widget.mode == "edit") {
			widget.container.getWidget("estrutura").enabled = false;
		} else {
			widget.container.getWidget("estrutura").enabled = true;
		}
	};

	this.salvarNovoItemEstrutura = function (widget) {
		var _this = this;

		widget.reload().then(function (_) {
			var currentRow = widget.currentRow;
			var widgetTipoArvProd = widget.container.getWidget('tipoarvoreproduto');
			var RowGroupName = widget.currentRow.NMARVOREPROD;

			currentRow.NRTPARVPROD = widgetTipoArvProd.currentRow.NRTPARVPROD;
			currentRow.NRTPARVPRODPAI = widgetTipoArvProd.currentRow.NRTPARVPROD;
			currentRow.NRARVOREPRODPAI = !(typeof currentRow.NRARVOREPRODPAI === "undefined" || currentRow.NRARVOREPRODPAI === null) ? currentRow.NRARVOREPRODPAI : null;

			if (!currentRow.__is_new && verificaParentesco(widget)) {
				if (_this.checkGroupingAndTypeTree(widget, RowGroupName) == false) {
					General.saveCrud(widget).then(function () {
						widget.list();
						widget.reload().then(function () {
							widget.view();
							widget.redraw();
						});
					});
				}
			} else if (currentRow.__is_new) {
				if (_this.checkGroupingAndTypeTree(widget, RowGroupName) == false) {
					General.saveCrud(widget).then(function () {
						currentRow = {};
						widget.reload();
					});
				}
			} else {
				ScreenService.showMessage("O grupo nao pode ser movido para um de seus grupos filhos");
			}
		});
	};

	this.salvarTipoArvore = function (widget) {
		var _this2 = this;

		var nomeTipoArvore = widget.currentRow.DSTPARVPROD;
		var widgetAgrupArvProd = widget.container.getWidget("estrutura");

		if (!widget.isValid()) return;

		widget.reload().then(function (_) {

			if (_this2.checkGroupingAndTypeTree(widget, nomeTipoArvore) == false) {
				General.saveCrud(widget).then(function () {
					if (!widget.currentRow.__is_new) {
						widget.list();
						widgetAgrupArvProd.enabled = true;
						widget.reload().then(function (_) {
							widget.view();
							widget.redraw();
						});
					} else {
						widget.currentRow = {};
						widget.reload();
					}
					widgetAgrupArvProd.enabled = true;
				});
			}
		});
	};

	this.checkGroupingAndTypeTree = function (widget, currentRowName) {
		var data = widget.dataSource.data;
		var dataMin = data.length - 1;
		var currentRow = widget.currentRow;

		if (data.length == 0) return false;
		for (var index in data) {
			if (widget.name === 'tipoarvoreproduto') {
				if (data[index].DSTPARVPROD == currentRowName) {
					ScreenService.showMessage("Impossível adicionar. Tipo de Árvore já existente.");
					widget.reload();
					break;
				}
			} else {
				if (currentRow.NRARVOREPRODPAI == null || currentRow.NRARVOREPRODPAI == "") {
					if (data[index].NMARVOREPROD == currentRowName) {
						if (currentRow.__is_new == true && currentRow._level == 1 || currentRow.__is_new == false && currentRow._level != 1) {
							ScreenService.showMessage("Impossível adicionar. Agrupamento de Árvore já existente.");
							widget.reload();
							break;
						}
					}
				}
			}
			if (index == dataMin) return false;
		}
	};

	var verificaParentesco = function verificaParentesco(widget) {

		var valido = true;

		if (!widget.currentRow.__is_new) {
			var rows = widget.dataSource.data;
			var nrarvoreprodpai = widget.currentRow.NRARVOREPRODPAI !== "undefined" && widget.currentRow.NRARVOREPRODPAI !== null ? widget.currentRow.NRARVOREPRODPAI.toString() : "";
			var nrarvoreprod = widget.currentRow.NRARVOREPROD.toString();
			rows.forEach(function (row) {
				if (row.NRARVOREPROD === nrarvoreprodpai) {
					if (row.NRARVOREPRODPAI === nrarvoreprod) valido = false;
				}
			});
		}

		return valido;
	};
};
Configuration(function (ContextRegister, eventEngine) {
	ContextRegister.register('ger01901_cadastrotipoarvoreproduto_controller', ger01901_cadastrotipoarvoreproduto_controller);
});

// FILE: ./assets/modules/produto/assets/js/controllers/ger01902_arvoreproduto_controller.js
var ger01902_arvoreproduto_controller = function ger01902_arvoreproduto_controller(ScreenService, templateManager, General, metaDataFactory) {

	var ignoredKeys = ["__rightActions", "__leftActions", "_children", "_parent", "__groupHeaders", "__index", "__isSelected", "__notSelectable", "$$hashKey"];
	var nivAnteOnCreation;

	this.calcMask = function (nvproduto) {
		var mask = getLocalVar('GER_CDPICTPROD');
		mask = mask.split('.');
		mask = mask.slice(0, parseInt(nvproduto));
		return mask.join('.');
	};

	this.cancelEditOrAdd = function (args) {
		var widget = args.owner.widget;
		if (widget.currentRow.__is_new) {
			widget.dataSource.data.pop();
			ScreenService.closeSwipe();
			widget.list();
		} else {
			General.backOrCancel(args);
		}
		this.backToDefaultMask();
	};

	this.backToDefaultMask = function () {
		var widget = templateManager.container.getWidget('arvoreProdutoGrid');
		var arvprodField = widget.getField("CDARVPROD");

		arvprodField.mask.params.mask = getLocalVar('GER_CDPICTPROD');
		//var newField = metaDataFactory.fieldFactory(arvprodField, widget);
		//widget.fields.splice(0, 1, newField);
	};

	this.deleteProduct = function (widget) {
		var parentOnDataset = false;
		var row = Util.clone(widget.currentRow, ignoredKeys);

		if (widget.currentRow._parent) parentOnDataset = widget.dataSource.data.filter(function (row) {
			return row.CDARVPROD == widget.currentRow._parent.CDARVPROD;
		})[0];

		General.callRestEngine('cadEst_produto#/produto_para_arvore/remove', "Row", row).then(function () {
			ScreenService.closeSwipe().then(function () {
				widget.list();
				if (parentOnDataset) {
					parentOnDataset._childCount -= 1;
					if (parentOnDataset._childCount <= 0) {
						parentOnDataset._hasChild = false;
						parentOnDataset._opened = false;
					}
				}
				widget.dataSource.data = widget.dataSource.data.filter(function (data) {
					return data != widget.currentRow;
				});
			});
		}.bind(this), this.errorRequest);
	};

	this.errorRequest = function (error) {
		if (error.data.error) {
			ScreenService.showMessage(error.data.error);
		} else {
			ScreenService.showMessage(error);
		}
		ScreenService.hideLoader();
	};

	this.newTree = function (widget) {
		ScreenService.showLoader();
		widget.prodnivante = Util.clone(widget.currentRow, ignoredKeys);
		nivAnteOnCreation = widget.dataSource.data.filter(function (row) {
			return row.CDARVPROD == widget.prodnivante.CDARVPROD;
		})[0];
		var row = {
			'PARENTCDPRODUTO': widget.prodnivante.CDARVPROD || null,
			'PARENTNVPRODUTO': widget.prodnivante.CDNVPRODUTO || null
		};
		General.callRestEngine('cadEst_produto#/sugestedArvprod', 'Row', row).then(function (request) {
			var arvprodField = templateManager.container.getWidget('arvoreProdutoGrid').getField("CDARVPROD");
			var sugested = request.dataset.sugestedArvprod[0];

			var parentMask = parseInt(widget.prodnivante.CDNVPRODUTO || 0) + 1;
			var mask = this.calcMask(parentMask);
			arvprodField.mask.params.mask = mask;
			widget.newRow();

			widget.currentRow.CDNVPRODUTO = parseInt(widget.prodnivante.CDNVPRODUTO || 0) + 1;
			widget.currentRow.CDPRODNIVANTE = widget.prodnivante.CDPRODUTO || null;
			widget.currentRow.CDARVPRODNIVANTE = widget.prodnivante.CDARVPROD || null;
			widget.currentRow.CDARVPROD = sugested.CDDARVPROD;
			//var newField = metaDataFactory.fieldFactory(arvprodField, widget);
			//widget.fields.splice(0, 1, newField);

			ScreenService.hideLoader();
		}.bind(this), this.errorRequest);
	};

	this.newTreeLevelOne = function (widget) {
		widget.currentRow = {};
		this.newTree(widget);
	};

	this.openSwipe = function (widget) {
		ScreenService.openSwipe(widget).then(function () {
			this.rulesOpenSwipe(widget);
		}.bind(this));
	};

	this.penultimateLevel = function (level) {
		var maxLevel = General.getLevelByMask('GER_CDPICTPROD', 1).length;
		if (maxLevel - 1 > level) {
			return true;
		} else {
			return false;
		}
	};

	this.rulesOpenSwipe = function (widget) {
		var afterSave = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

		//var arvprodField = templateManager.container.getWidget('arvoreProdutoGrid').getField("CDARVPROD");

		if (widget.mode != 'edit' && !widget.currentRow.__is_new) {
			// widget.view();
			if (widget.currentRow._hasChild || this.penultimateLevel(widget.currentRow.CDNVPRODUTO)) {
				widget.getAction('adicionar').isVisible = true;
			} else {
				widget.getAction('adicionar').isVisible = false;
			}

			if (widget.currentRow._hasChild) {
				widget.getAction('excluir').isVisible = false;
			} else {
				widget.getAction('excluir').isVisible = true;
			}
		}
		if (afterSave) {
			if (widget.currentRow._hasChild || this.penultimateLevel(widget.currentRow.CDNVPRODUTO)) {
				widget.getAction('adicionar').isVisible = true;
			} else {
				widget.getAction('adicionar').isVisible = false;
			}

			if (widget.currentRow._hasChild) {
				widget.getAction('excluir').isVisible = false;
			} else {
				widget.getAction('excluir').isVisible = true;
			}
		}
		//var mask = this.calcMask(widget.currentRow.CDNVPRODUTO || 1);
		// arvprodField.mask.params.mask = mask;
		//var newField = metaDataFactory.fieldFactory(arvprodField, widget);
		//widget.fields.splice(0, 1, newField);
	};

	this.save = function (widget) {
		var row = Util.clone(widget.currentRow, ignoredKeys);
		row.CDARVPROD = valueDesmasked(row.CDARVPROD.toUpperCase());

		if (widget.isValid()) {
			General.callRestEngine('cadEst_produto#/produto_para_arvore/save', "Row", row).then(function (success) {
				widget.activate();
				this.rulesOpenSwipe(widget, true);
				if (widget.currentRow.__is_new) {
					var retCdproduto = success.dataset.columnsToReturn[0].CDPRODUTO;
					widget.currentRow.CDPRODUTO = retCdproduto;
					widget.currentRow.__is_new = false;
					widget.getField('CDARVPROD').mask.params.mask = "@getLocalVar('GER_CDPICTPROD')@";
					widget.view();
					if (nivAnteOnCreation || row.CDNVPRODUTO > 1) {
						if (!nivAnteOnCreation ? true : !nivAnteOnCreation._opened) {
							widget.dataSource.data.pop();
						}
						if (nivAnteOnCreation) {
							nivAnteOnCreation._hasChild = true;
							nivAnteOnCreation._childCount += 1;
						}
					}
					widget.getAction('excluir').isVisible = true;
				} else {
					widget.view();
				}
			}.bind(this), this.errorRequest);
		}
	};

	this.newGroupOperRules = function (widgetGroupOper) {
		var widgetProductTree = widgetGroupOper.getParent();
		widgetGroupOper.currentRow.CDPRODUTO = widgetProductTree.currentRow.CDPRODUTO;
	};

	this.saveMaskAction = function (widget) {
		var gridArvore = widget.getParent();
		var fieldMask = widget.getField('CDPICTPROD');
		fieldMask.value(fieldMask.value().toLowerCase());
		widget.dataSource.name = 'cadEst#/paramgeralMask';
		General.saveCrud(widget).then(function (success) {
			widget.dataSource.name = 'cadEst#/crud/paramgeral';
			ScreenService.closePopup();
			ScreenService.closeSwipe();
			gridArvore.activate();
		});
	};

	this.preventUnwantedKeys = function (args) {
		var arrAllowedKeys = ['9', 'a', 'A', '.'];
		if (!arrAllowedKeys.includes(args.e.key)) {
			args.e.preventDefault();
		}
	};

	this.setCurrentRowWithData = function (widget) {
		widget.currentRow = widget.dataSource.data[0];
	};

	this.changeMaskVisibility = function (widget) {
		var maskWidget = widget.container.getWidget('maskPopup');
		var fieldMask = maskWidget.getField('CDPICTPROD');

		fieldMask.readOnlyOnEdit = widget.dataSource.data.length == 0 ? false : true;
		fieldMask.readOnly = widget.dataSource.data.length == 0 ? false : true;
	};

	this.codArvToUpperCase = function (widget) {
		var fieldCodArv = widget.getField('CDARVPROD');
		fieldCodArv.value(valueDesmasked(widget.currentRow.CDARVPROD.toUpperCase()));
	};

	var valueDesmasked = function valueDesmasked(value) {
		return value.split('.').join('');
	};

	this.changeDataSourceBeforeReport = function (widget) {
		console.log(widget);
	};
};

Configuration(function (ContextRegister, eventEngine) {
	ContextRegister.register('ger01902_arvoreproduto_controller', ger01902_arvoreproduto_controller);
});

// FILE: ./assets/modules/produto/assets/js/controllers/ger01903_impostoproduto_controller.js
var ger01903_impostoproduto_controller = function ger01903_impostoproduto_controller(ScreenService, templateManager, General, ZhFilterPreferences) {

	var self = this;

	this.openFilter = function (args) {
		var widget = args.owner;
		ZhFilterPreferences.startFiltering(widget);
	};

	this.setUnitImposto = function (widget) {
		widget.currentRow.CDFILIAL = General.getFieldValue('CDFILIAL', 'impostos');
	};

	this.configAfterApply = function (widget) {
		var widgetImposto = templateManager.container.getWidget('impostos');
		widgetImposto.currentRow.CDFILIAL = widget.currentRow.CDFILIAL;
		widgetImposto.dataSourceFilter[4].value = widget.currentRow.CDFILIAL;
		widgetImposto.reload().then(function (response) {
			widgetImposto.currentRow = response.dataset.paraVendasImpostoProduto[0];
		});
	};

	this.loadDataImposto = function (args) {
		var widget = args.owner;
		var widgetImpo = templateManager.container.getWidget('impostos');
		var fieldPIS = widgetImpo.getField(VRALIQPIS_FIELD),
		    fieldCOFINS = widgetImpo.getField(VRALIQCOFINS_FIELD);
		widgetImpo.dataSourceFilter[3].value = widget.__filterPopup.currentRow.CDFILIAL;
		widgetImpo.reload().then(function (data) {
			widgetImpo.currentRow = data.dataset.paraVendasImpostoProduto[0];
			templateManager.container.getWidget('prodConfig').reload();
			fieldPIS.readOnly = fieldCOFINS.readOnly = !(!!widgetImpo.currentRow.CDCSTPISCOF && !!widgetImpo.currentRow.CDCFOPPFIS);
		});
	};

	this.configTelaOnChange = function (args) {
		var field = args.owner.field;
		var fieldDSBUTTON = field.widget.getField('DSBUTTON');
		fieldDSBUTTON.readOnly = field.value() == null || field.value() == '';
		fieldDSBUTTON.dataSourceFilter[2].value = field.widget.currentRow.NRCONFTELA;
		fieldDSBUTTON.value(null);
	};

	var IMPOSTPROD_WIDGET = 'paraVendaImpostoProduto',
	    IMPOSTPRODPOPUP_WIDGET = 'paraVendaImpostoProdutoPopup',
	    NMPRODINICIAL_FIELD = 'NMPRODINICIAL',
	    NMPRODFINAL_FIELD = 'NMPRODFINAL',
	    CDCSTICMS_FIELD = 'CDCSTICMS',
	    CDCSTPISCOF_FIELD = 'CDCSTPISCOF',
	    VRALIQPIS_FIELD = 'VRALIQPIS',
	    VRALIQCOFINS_FIELD = 'VRALIQCOFINS',
	    CDCEST_FIELD = 'CDCEST',
	    NMPRODUTOFIN_FIELD = 'NMPRODUTOFIN';

	this.editImposto = function (widget) {
		General.widgetEdit(widget);

		widget.currentRow.CDFILIAL = Array.isArray(widget.currentRow.CDFILIAL) ? widget.currentRow.CDFILIAL : [widget.currentRow.CDFILIAL];
		widget.currentRow.NMFILIAL = Array.isArray(widget.currentRow.NMFILIAL) ? widget.currentRow.NMFILIAL : [widget.currentRow.NMFILIAL];
		widget.getField('CDFILIAL').reload();
	};

	this.cancelNewTax = function (args) {
		var widget = args.owner.widget;
		General.widgetCancelForm(widget);
		delete widget.getField('CDFILIAL').validations.required;
	};

	this.saveImposto = function (widget) {
		if (widget.isValid()) {
			widget.saveRow().then(function (response) {
				widget.currentRow.changed = false;
				widget.reload();
				widget.view();
			}).catch(function (response) {
				ScreenService.errorNotification(response.data.error);
			});
		}
	};

	this.impostosAfterMoveRow = function (args) {
		var widget = args.owner;
		widget.activate();

		setAliquotaVisibility(widget, false);

		widget.fields.forEach(function (field) {
			if (field.dataSourceFilter !== undefined) {
				field.dataSourceFilter.forEach(function (filter) {
					if (filter.name == 'CDFILIAL') {
						filter.value = widget.currentRow.CDFILIAL;
					}
				});
			}
		});
	};

	this.setCDSITUTRIBorCDSITUTRIBNFE = function (args) {
		var widget = args.owner.field.widget;

		widget.currentRow.CDSITUTRIB = widget.currentRow.CDCSTPISCOF;
		widget.currentRow.CDSITUTRIBNFE = widget.currentRow.CDCSTPISCOF;
	};

	this.setClearImposto = function (args) {
		var widget = args.owner.field.widget;
		widget.currentRow.CDCSTICMS = '';
		widget.getField('CDCSTICMS').value('');
	};

	var setAliquotaVisibility = function setAliquotaVisibility(widget, setNull) {
		var fieldPIS = widget.getField(VRALIQPIS_FIELD),
		    fieldCOFINS = widget.getField(VRALIQCOFINS_FIELD);

		fieldPIS.readOnly = fieldCOFINS.readOnly = !(!!widget.currentRow.CDCSTPISCOF && !!widget.currentRow.CDCFOPPFIS);

		if (setNull) widget.currentRow.VRALIQCOFINS = widget.currentRow.VRALIQPIS = null;

		self.updateDataSourceFilter(widget, fieldPIS);
		self.updateDataSourceFilter(widget, fieldCOFINS);

		widget.activate();
	};

	this.updateDataSourceFilter = function (widget, widgetToUpdate) {
		widgetToUpdate.dataSourceFilter.forEach(function (filter) {

			filter.value = Util.clone(widget.currentRow[filter.name]);

			if (filter.name === 'NRORG') {
				filter.value = getLocalVar('NRORG');
			}
		});
		return widgetToUpdate.reload();
	};

	this.isAliquotaVisible = function (widget) {

		setAliquotaVisibility(widget, true);
	};

	this.saveImpostoProduto = function (widget) {
		var row = widget.currentRow;
		row.CDNVPRODUTO = General.getLevelByMask('GER_CDPICTPROD', 1).length;
		if (widget.isValid()) {

			row.VRPEALIMPFIS = General.valueToFloat(row.VRPEALIMPFIS);
			row.VRPERCREDUCAO = General.valueToFloat(row.VRPERCREDUCAO);
			row.VRALIQIBPT = General.valueToFloat(row.VRALIQIBPT);
			row.VRALIQIBPTES = General.valueToFloat(row.VRALIQIBPTES);

			if (parseFloat(row.VRPEALIMPFIS < 0)) {
				row.VRPEALIMPFIS = row.VRPEALIMPFIS * -1;
			}

			if (parseFloat(row.VRPERCREDUCAO < 0)) {
				row.VRPERCREDUCAO = row.VRPERCREDUCAO * -1;
			}

			if (parseFloat(row.VRALIQIBPT < 0)) {
				row.VRALIQIBPT = row.VRALIQIBPT * -1;
			}

			if (parseFloat(row.VRALIQIBPTES < 0)) {
				row.VRALIQIBPTES = row.VRALIQIBPTES * -1;
			}

			if (!row.CDCSTPISCOF) {
				row.VRALIQPIS = 0;
				row.VRALIQCOFINS = 0;
			}
			General.widgetSave(widget).then(function (response) {
				if (response.messages[0].type == 'W') {
					ScreenService.showMessage(response.messages[0].message, 'alert');
				} else {
					ScreenService.showMessage('Certifique-se de que a aba Produto->Fiscal foi parametrizada. Unidades já cadastradas, foram alteradas!', 'alert');
				}
				delete widget.getField('CDFILIAL').validations.required;
				widget.reload();
			}).catch(function (response) {
				ScreenService.errorNotification(response.data.error);
			});
		}
	};

	this.newProdTax = function (args) {
		var widget = args.owner.widget;
		widget.getField('CDFILIAL').validations.required = true;
		General.widgetNewRow(widget);
		widget.currentRow.NRORG = getLocalVar('NRORG');
		widget.currentRow.CDPRODUTO = General.getFieldValue('CDPRODUTO', 'Detalhamento');
		widget.currentRow.CDARVPROD = General.getFieldValue('CDARVPROD', 'Detalhamento');
		widget.currentRow.NMPRODUTO = General.getFieldValue('NMPRODUTO', 'Detalhamento');
		widget.currentRow.CDPRPAITABPR = General.getFieldValue('CDPRODUTO', 'Detalhamento');
		widget.currentRow.CDBARPRODUTO = General.getFieldValue('CDBARPRODUTO', 'Detalhamento');
		if (widget.appliedFilter.FILTER_ROW.CDFILIAL !== '') {
			widget.currentRow.CDFILIAL = widget.appliedFilter.FILTER_ROW.CDFILIAL;
		}
		widget.reload();
	};

	this.exportImposto = function (widget) {
		var exportPopup = templateManager.container.getWidget('exportImpos');
		ScreenService.openPopup(exportPopup);
		exportPopup.currentRow = widget.currentRow;
		exportPopup.currentRow.CDFILIALORIG = exportPopup.currentRow.CDFILIAL;
		delete exportPopup.currentRow.CDFILIAL;
		templateManager.container.getWidget('impostos').activate();
	};

	this.saveExport = function (widget) {
		var row = widget.currentRow;
		row.CDNVPRODUTO = General.getLevelByMask('GER_CDPICTPROD', 1).length;
		if (widget.isValid()) {

			row.VRPEALIMPFIS = General.valueToFloat(row.VRPEALIMPFIS);
			row.VRPERCREDUCAO = General.valueToFloat(row.VRPERCREDUCAO);
			row.VRALIQIBPT = General.valueToFloat(row.VRALIQIBPT);
			row.VRALIQIBPTES = General.valueToFloat(row.VRALIQIBPTES);

			row.VRPEALIMPFIS = parseFloat(row.VRPEALIMPFIS) < 0 ? row.VRPEALIMPFIS * -1 : row.VRPEALIMPFIS;
			row.VRPERCREDUCAO = parseFloat(row.VRPERCREDUCAO) < 0 ? row.VRPERCREDUCAO * -1 : row.VRPERCREDUCAO;
			row.VRALIQIBPT = parseFloat(row.VRALIQIBPT) < 0 ? row.VRALIQIBPT * -1 : row.VRALIQIBPT;
			row.VRALIQIBPTES = parseFloat(row.VRALIQIBPTES) < 0 ? row.VRALIQIBPTES * -1 : row.VRALIQIBPTES;

			if (!row.CDCSTPISCOF) {
				row.VRALIQPIS = 0;
				row.VRALIQCOFINS = 0;
			}
			row.__is_new = true;
			General.callRestEngine('cadEst#/ger01900_cadastroproduto_venda_imposto_export', 'Row', row);
			delete widget.getField('CDFILIAL').validations.required;
			ScreenService.closePopup(widget);
			ScreenService.closeSwipe();
		}
	};
};

Configuration(function (ContextRegister, eventEngine) {
	ContextRegister.register('ger01903_impostoproduto_controller', ger01903_impostoproduto_controller);
});
//# sourceMappingURL=app.js.map
