var SafraController = function($scope, templateManager, $element) {

	var currentSelectedElement;

	this.TColorToHex = function(TColor) {
		var rgb = this.TColorToRGB(TColor);
		return this.rgbToHex(rgb);
	};

	this.TColorToRGB = function(TColor) {
        var r = TColor & 0xFF;
        var g = (TColor >> 8) & 0xFF;
        var b = (TColor >> 16) & 0xFF;
        return [r,g,b];
	};

	this.rgbToHex = function (rgb) {
	    return "#" + ((1 << 24) + (rgb[0] << 16) + (rgb[1] << 8) + rgb[2]).toString(16).slice(1);
	};

	this.initColors = function(field) {
		var currentRow = $scope.field.widget.currentRow;
		var safra = currentRow[field.colorsFlag.OPTION1];
		var initFin = currentRow[field.colorsFlag.OPTION2];
		var entre = currentRow[field.colorsFlag.OPTION3];
		
		var htmlParentContainer = $element.get(0);
		var flagElements = htmlParentContainer.querySelectorAll('.flag');

		safra = safra? this.TColorToHex(safra) : 'transparent';
		initFin = initFin? this.TColorToHex(initFin) : 'transparent';
		entre = entre? this.TColorToHex(entre) : 'transparent';

		flagElements[0].style.backgroundColor = safra;
		flagElements[1].style.backgroundColor = initFin;
		flagElements[2].style.backgroundColor = entre;

		var colorMonths = currentRow[field.propertieToChange];
		var months = htmlParentContainer.querySelectorAll('.month');
		this.initColorsMonth(months, [safra, initFin, entre], colorMonths);
	};

	this.initColorsMonth = function(months, colorFlags, colorMonths) {
		var color;
		if (!colorMonths) {
			months.forEach(function(element, key) {
				element.children[1].style.backgroundColor = 'transparent';
			});
		} else {
			colorMonths = colorMonths.split('');
			months.forEach(function(element) {
				var month = $(element).attr('month');
				var monthCorlorElement = element.children[1];
				
				var codeFlag = colorMonths[month -1];
				var colorMonth =  codeFlag != ' ' ? colorFlags[codeFlag -1] : 'transparent';
	
				monthCorlorElement.style.backgroundColor = colorMonth;
			});
		}	
	};

	this.getOptLabel = function(field, opt) {
		if (opt == '1') {	
			return field.option1 === "" || field.option1 ? field.option1 : "option1 not found";
		} else if (opt == '2') {
			return field.option2 === "" || field.option2 ? field.option2 : "option2 not found";
		} else {
			return field.option3 === "" || field.option3 ? field.option3 : "option3 not found";
		}
	};

	this.selectFlag = function($event) {
		if (this.isEdit()) {
			if (currentSelectedElement === $event.currentTarget) {
				currentSelectedElement.style.backgroundColor = "transparent";
				currentSelectedElement = null;
			} else {
				if (currentSelectedElement) {
					currentSelectedElement.style.backgroundColor = "transparent";
				}
				currentSelectedElement = $event.currentTarget;
				currentSelectedElement.style.backgroundColor = '#67a965';
			}

		}
	};

	this.setInMonth = function($event, field) {
		if (this.isEdit() && currentSelectedElement) {
			var flagElement = currentSelectedElement.children[0];
			var color = flagElement.style.backgroundColor;
			var monthElement = $event.currentTarget.children[1];
			monthElement.style.backgroundColor = color;
			var month = $($event.currentTarget).attr('month');
			this.changePropertieInCurrentRow(field, month);
		}
	};	

	this.changePropertieInCurrentRow = function(field, month) {
		if (!field.propertieToChange) {
			throw 'propertieToChange not found';
		} else {
			var option = $(currentSelectedElement).attr('option');
			var propertieToChange = field.propertieToChange;
			var value;
			if (!field.widget.currentRow[propertieToChange]) {
				value = '          ';
			} else {
				 value = field.widget.currentRow[propertieToChange];
			}
			value = value.split('');
			value[month -1] = option;
			value = value.join('');
			field.widget.currentRow[propertieToChange] = value;
		}
	};

	this.isEdit = function() {
		var widget = $scope.field.widget;
		if (widget.mode === 'edit') {
			return true;
		} else {
			return false;
		}
	};

	this.isCurrentMonth = function(month) {
		var currentMonth = moment().month() + 1;
		if (currentMonth == month) {
			return true;
		} else {
			return false;
		}
	};

	$scope.$watch(function() {
		return templateManager.container ? templateManager.container.getActiveWidget().currentRow : false;
	}, function(){
		var widget = templateManager.container.getActiveWidget();
		var fieldsSafra = widget.fields.filter(function(field) {
			return field.template === 'safra-component#field/safra.html' && field.isVisible;
		});
		fieldsSafra.forEach(function(field) {
			this.initColors(field);
		}, this);
	}.bind(this));
};